package com.ruoyi.ems.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.ems.mapper.AdmBoxElecEqptMapper;
import com.ruoyi.ems.domain.AdmBoxElecEqpt;
import com.ruoyi.ems.service.IAdmBoxElecEqptService;

/**
 * 动力箱柜电气设备Service业务层处理
 * 
 * @author ruoyi
 * @date 2024-09-03
 */
@Service
public class AdmBoxElecEqptServiceImpl implements IAdmBoxElecEqptService 
{
    @Autowired
    private AdmBoxElecEqptMapper admBoxElecEqptMapper;

    /**
     * 查询动力箱柜电气设备
     * 
     * @param id 动力箱柜电气设备主键
     * @return 动力箱柜电气设备
     */
    @Override
    public AdmBoxElecEqpt selectAdmBoxElecEqptById(Long id)
    {
        return admBoxElecEqptMapper.selectAdmBoxElecEqptById(id);
    }

    /**
     * 查询动力箱柜电气设备列表
     * 
     * @param admBoxElecEqpt 动力箱柜电气设备
     * @return 动力箱柜电气设备
     */
    @Override
    public List<AdmBoxElecEqpt> selectAdmBoxElecEqptList(AdmBoxElecEqpt admBoxElecEqpt)
    {
        return admBoxElecEqptMapper.selectAdmBoxElecEqptList(admBoxElecEqpt);
    }

    /**
     * 新增动力箱柜电气设备
     * 
     * @param admBoxElecEqpt 动力箱柜电气设备
     * @return 结果
     */
    @Override
    public int insertAdmBoxElecEqpt(AdmBoxElecEqpt admBoxElecEqpt)
    {
        return admBoxElecEqptMapper.insertAdmBoxElecEqpt(admBoxElecEqpt);
    }

    /**
     * 修改动力箱柜电气设备
     * 
     * @param admBoxElecEqpt 动力箱柜电气设备
     * @return 结果
     */
    @Override
    public int updateAdmBoxElecEqpt(AdmBoxElecEqpt admBoxElecEqpt)
    {
        return admBoxElecEqptMapper.updateAdmBoxElecEqpt(admBoxElecEqpt);
    }

    /**
     * 批量删除动力箱柜电气设备
     * 
     * @param ids 需要删除的动力箱柜电气设备主键
     * @return 结果
     */
    @Override
    public int deleteAdmBoxElecEqptByIds(Long[] ids)
    {
        return admBoxElecEqptMapper.deleteAdmBoxElecEqptByIds(ids);
    }

    /**
     * 删除动力箱柜电气设备信息
     * 
     * @param id 动力箱柜电气设备主键
     * @return 结果
     */
    @Override
    public int deleteAdmBoxElecEqptById(Long id)
    {
        return admBoxElecEqptMapper.deleteAdmBoxElecEqptById(id);
    }
}
